/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.search.controller;

import java.util.HashMap;
import java.util.Map;

import org.springframework.web.servlet.ModelAndView;

import com.perforce.search.model.impl.ErrorModel;
import com.perforce.search.model.impl.ErrorModels;

public final class ResponseBuilder {

    private ResponseBuilder() {
    }

    public static ModelAndView buildResponse(final Object payload) {
	// status OK
	return buildResponse(ErrorModels.Error_OK, payload);
    }

    public static ModelAndView buildResponse(final ErrorModel error) {
	return buildResponse(error, null);
    }

    public static ModelAndView buildResponse(final String viewName,
	    final ErrorModel error) {
	// status OK
	return buildResponse(viewName, error, null);
    }

    public static ModelAndView buildResponse(final ErrorModel error,
	    final Object payload) {
	return buildResponse("jsonMapper", error, payload);
    }

    public static ModelAndView buildResponse(final String viewName,
	    final ErrorModel error, final Object payload) {
	// status OK
	ModelAndView mav = new ModelAndView(viewName);
	mav.addObject("payload", payload);
	Map<String, String> status = new HashMap<String, String>();
	status.put("code", String.valueOf(error.getCode()));
	status.put("message", error.getMessage());
	mav.addObject("status", status);
	return mav;
    }
}
